@@ -55,7 +55,7 @@ def search_repo(repository, pattern) -> tuple:
     return results
 
 
-def git_regex_search(url, pattern):
+def Search(url, pattern):
     # print(type(args))
     #print(args)
     if url:
@@ -120,7 +120,7 @@ if __name__ == '__main__':
         pattern = "latestRoundData"
     
     if args.url:
-        git_regex_search(args.url, pattern)
+        Search(args.url, pattern)
     else:
         print(colored("Print Something is wrong"), "red")
         exit(-3)
\ No newline at end of file
